==> appfs-21.02.tar.gz: usr/local/www/berogui/modules/RebootReset/factoryreset_popup.php <==
<?php
/*
 * @file
 * Modal Form to factory reset hardware configuration when E1/T1 module is plugged
 */
include_once("/usr/www/include/SQLite2ToSQLite3.php");
require_once ('/usr/local/www/berogui/misc/database.php');
$ba = new beroAri();

chdir('../..');
require_once ('/usr/local/www/berogui/includes/lang.php');
require_once ('/usr/local/www/berogui/includes/session.php');

// functions 
function hw_mode($tab, $act_mode)
{
        $html_str = '';

        if ($act_mode == 'hdlc') {
                $html_str .=    $tab . "\t<option value='cas'>cas</option>\n" .
                                $tab . "\t<option value='hdlc' selected>ccs</option>\n";
        } else {
                $html_str .=    $tab . "\t<option value='cas' selected>cas</option>\n" .
                                $tab . "\t<option value='hdlc'>ccs</option>\n";
        }

        return $html_str;
}

function hw_protocol ($tab, $protocol)
{
        $html_str = '';

        if ($entry['protocol'] == "t1") {
                $html_str .=    $tab . "\t<option value=1 selected>T1</option>\n" .
                                $tab . "\t<option value=0>E1</option>\n";
        }
        else {
                $html_str .=    $tab . "\t<option value=1>T1</option>\n" .
                                $tab . "\t<option value=0 selected>E1</option>\n";
        }

        return $html_str;
}

//CAS
$html_str =     "<form name='isdn_hw' id='pstn_hw' class='form-horizontal' action='modules/RebootReset/recreate_sbc.php?val=yes' method='POST'>\n" .
                "\t<input type='hidden' name='keep_hw_set' value='true' />\n";

// Keep Settings
if (isset($_GET['Set']) && strcmp($_GET['Set'], 'true') == 0) {
        $html_str .= "\t<input type='hidden' name='keep_set' value='true'/>\n";
}

if (isset($_GET['AclSet']) && strcmp($_GET['AclSet'], 'true') == 0) {
	$html_str .= "\t<input type='hidden' name='keep_acl_set' value='true'/>\n";
}

if (isset($_GET['CloudSet']) && strcmp($_GET['CloudSet'], 'true') == 0) {
        $html_str .= "\t<input type='hidden' name='keep_cloud_set' value='true'/>\n";
}

if (isset($_GET['SipSet']) && strcmp($_GET['SipSet'], 'true') == 0) {
        $html_str .= "\t<input type='hidden' name='keep_sip_set' value='true'/>\n";
}

if (isset($_GET['AppSet']) && strcmp($_GET['AppSet'], 'true') == 0) {
        $html_str .= "\t<input type='hidden' name='keep_app_set' value='true'/>\n";
}

if (isset($_GET['PrefixSet']) && strcmp($_GET['PrefixSet'], 'true') == 0) {
        $html_str .= "\t<input type='hidden' name='keep_prefix_set' value='true'/>\n";
}

// select data base
$query_lif = $ba -> select("SELECT distinct lif, type FROM cas order by lif");
$ent = $ba -> fetch_array($query_lif);

do
{
	if (isset($ent['lif'])) 
	{
        	$query = $ba -> select("select * from cas where lif='" . $ent['lif'] . "'");

        	$html_str .=    "\n" .
        	                "\t<table class='table table-striped table-bordered' style='width:90% !important; margin:auto;'> \n" .
        	                "\t\t<tr><th colspan='7'><div class='text-center'>" . HARDWARE_CARD_TYPE_DIS . ":&nbsp;" . $ent['type'] ."&nbsp;&nbsp;" . HARDWARE_LINE_INTERFACE_DIS . ":&nbsp;" . $ent['lif'] . "&nbsp;&nbsp;</div></th></tr>\n";

        	while ($entry = $ba -> fetch_array($query))
		{
                	$html_str .=    "\t\t<tr>\n" .
                	                "\t\t\t<td><b>" . HARDWARE_PORT_DIS . ":</b>&nbsp;" . $entry['port'] . "&nbsp;</td>\n" .
                	                "\t\t\t<td colspan='4'>\n" .
                	                "\t\t\t\t<div class='col-sm-5'><b>" . HARDWARE_INTERFACE_TYPE_DIS . ":</b></div>\n" .
                	                "\t\t\t\t<div class='col-sm-7'>\n" .
                	                "\t\t\t\t\t<select class='form-control' name='interface_type" . $entry['port'] . "'>\n" .

                	                hw_mode("\t\t\t\t\t", $entry['port_type']) .

                	                "\t\t\t\t\t</select>\n" .
                	                "\t\t\t\t</div>\n" .
                	                "\t\t\t\t<input type=hidden name=id_upd[] value=" . $entry['port'] . ">\n" .
               	                	"\t\t\t\t<input type=hidden name=type[] value='cashw'>\n" .
                                	"\t\t\t</td>\n" .
                                	"\t\t\t<td>\n" .
                                	"\t\t\t\t<div class='col-sm-3'><b>" . HARDWARE_PROTOCOL_DIS . ":</b></div>\n" .
                                	"\t\t\t\t<div class='col-sm-7'>\n" .
                                	"\t\t\t\t\t<select class='form-control' name='t1e1" . $entry['port'] . "' onmouseover=\"Tip('" . "T1 or E1" . "')\" onmouseout='UnTip()'>\n" .

                               		hw_protocol ("\t\t\t\t\t", $entry['protocol']) .

                                	"\t\t\t\t\t</select>\n" .
                                	"\t\t\t\t</div>\n" .
                                	"\t\t\t\t<input type=hidden name=id_upd[] value=" . $entry['port'] . ">\n" .
                                	"\t\t\t\t<input type=hidden name=type[] value='cas'>\n" .
                                	"\t\t\t</td>\n" .
                                	"\t\t</tr>\n";
        	}
	}
	else 
	{
                exec("/bin/cat /sys/class/beronet/li*/module", $lifs);
                exec("/bin/cat /sys/class/beronet/gateway/li_count", $li_count); // not necessary; count($lifs) is enough

                for ($i=0; $i<$li_count[0]; $i++)
                {
                        if (preg_match("#t1e1#", $lifs[$i]))
                        {
                                $html_str .=    "\n" .
                                                "\t<table class='table table-striped table-bordered' style='width:90% !important; margin:auto;'> \n" .
                                                "\t\t<tr><th colspan='7'><div class='text-center'>" . HARDWARE_CARD_TYPE_DIS . ":&nbsp;" . $lifs[$i] ."&nbsp;&nbsp;" . HARDWARE_LINE_INTERFACE_DIS . ":&nbsp;" . $i . "&nbsp;&nbsp;</div></th></tr>\n";

                                $j = 1;
                                $nb_port = 1;
                                switch ($lifs[$i])
                                {
                                        case 'bf4t1e1':
                                                $nb_port = 4;
                                                break;
                                        case 'bf2t1e1':
                                                $nb_port = 2;
                                                break;
                                        case 'bf1t1e1':
                                        default:
                                                break;
                                }

				do
				{
                                	$html_str .=    "\t\t<tr>\n" .
                                        	        "\t\t\t<td><b>" . HARDWARE_PORT_DIS . ":</b>&nbsp; $j &nbsp;</td>\n" .
                                        	        "\t\t\t<td colspan='4'>\n" .
                                        	        "\t\t\t\t<div class='col-sm-5'><b>" . HARDWARE_INTERFACE_TYPE_DIS . ":</b></div>\n" .
                                        	        "\t\t\t\t<div class='col-sm-7'>\n" .
                                        	        "\t\t\t\t\t<select class='form-control' name='interface_type$j'>\n" .

                                        	        hw_mode("\t\t\t\t\t", "hdlc") .

                                       	        	"\t\t\t\t\t</select>\n" .
                                                	"\t\t\t\t</div>\n" .
                                                	"\t\t\t\t<input type=hidden name=id_upd[] value=$j>\n" .
                                                	"\t\t\t\t<input type=hidden name=type[] value='cashw'>\n" .
                                                	"\t\t\t</td>\n" .
                                                	"\t\t\t<td>\n" .
                                                	"\t\t\t\t<div class='col-sm-3'><b>" . HARDWARE_PROTOCOL_DIS . ":</b></div>\n" .
                                                	"\t\t\t\t<div class='col-sm-7'>\n" .
                                                	"\t\t\t\t\t<select class='form-control' name='t1e1$j' onmouseover=\"Tip('" . "T1 or E1" . "')\" onmouseout='UnTip()'>\n" .
	
         	                                      	hw_protocol ("\t\t\t\t\t", "e1") .

                                                	"\t\t\t\t\t</select>\n" .
                                                	"\t\t\t\t</div>\n" .
                                                	"\t\t\t\t<input type=hidden name=id_upd[] value=$j>\n" .
                                                	"\t\t\t\t<input type=hidden name=type[] value='cas'>\n" .
                                                	"\t\t\t</td>\n" .
                                                	"\t\t</tr>\n";

					$j++;
				}
				while ($j <= $nb_port);
                        }
                }

	}	

        $html_str .= "\t</table>\n";
}
while ($ent = $ba -> fetch_array($query_lif));

$html_str .=    "\t<div class='text-center' style='margin-top: 20px;'><input type='submit' class='btn btn-default' value='" . FACTORY_RESET_APPLY . "'></div>\n" .
                "</form>\n";

echo $html_str;

==> appfs-24.01.01-rc39.tar.gz: usr/local/www/berogui/modules/RebootReset/factoryreset_popup.php <==
<?php
/*
 * @file
 * Modal Form to factory reset hardware configuration when E1/T1 module is plugged
 */
include_once("/usr/www/include/SQLite2ToSQLite3.php");
require_once ('/usr/local/www/berogui/misc/database.php');
$ba = new beroAri();

chdir('../..');
require_once ('/usr/local/www/berogui/includes/lang.php');
require_once ('/usr/local/www/berogui/includes/session.php');

// functions 
function hw_mode($tab, $act_mode)
{
        $html_str = '';

        if ($act_mode == 'hdlc') {
                $html_str .=    $tab . "\t<option value='cas'>cas</option>\n" .
                                $tab . "\t<option value='hdlc' selected>ccs</option>\n";
        } else {
                $html_str .=    $tab . "\t<option value='cas' selected>cas</option>\n" .
                                $tab . "\t<option value='hdlc'>ccs</option>\n";
        }

        return $html_str;
}

function hw_protocol ($tab, $protocol)
{
        $html_str = '';

        if ($entry['protocol'] == "t1") {
                $html_str .=    $tab . "\t<option value=1 selected>T1</option>\n" .
                                $tab . "\t<option value=0>E1</option>\n";
        }
        else {
                $html_str .=    $tab . "\t<option value=1>T1</option>\n" .
                                $tab . "\t<option value=0 selected>E1</option>\n";
        }

        return $html_str;
}

//CAS
$html_str =     "<form name='isdn_hw' id='pstn_hw' class='form-horizontal' action='modules/RebootReset/recreate_sbc.php?val=yes' method='POST'>\n" .
                "\t<input type='hidden' name='keep_hw_set' value='true' />\n";

// Keep Settings
if (isset($_GET['Set']) && strcmp($_GET['Set'], 'true') == 0) {
        $html_str .= "\t<input type='hidden' name='keep_set' value='true'/>\n";
}

if (isset($_GET['AclSet']) && strcmp($_GET['AclSet'], 'true') == 0) {
	$html_str .= "\t<input type='hidden' name='keep_acl_set' value='true'/>\n";
}

if (isset($_GET['ProvisioningSet']) && strcmp($_GET['ProvisioningSet'], 'true') == 0) {
	$html_str .= "\t<input type='hidden' name='keep_provisioning_set' value='true'/>\n";
}

if (isset($_GET['CloudSet']) && strcmp($_GET['CloudSet'], 'true') == 0) {
        $html_str .= "\t<input type='hidden' name='keep_cloud_set' value='true'/>\n";
}

if (isset($_GET['SipSet']) && strcmp($_GET['SipSet'], 'true') == 0) {
        $html_str .= "\t<input type='hidden' name='keep_sip_set' value='true'/>\n";
}

if (isset($_GET['AppSet']) && strcmp($_GET['AppSet'], 'true') == 0) {
        $html_str .= "\t<input type='hidden' name='keep_app_set' value='true'/>\n";
}

if (isset($_GET['PrefixSet']) && strcmp($_GET['PrefixSet'], 'true') == 0) {
        $html_str .= "\t<input type='hidden' name='keep_prefix_set' value='true'/>\n";
}

// select data base
$query_lif = $ba -> select("SELECT distinct lif, type FROM cas order by lif");
$ent = $ba -> fetch_array($query_lif);

do
{
	if (isset($ent['lif'])) 
	{
        	$query = $ba -> select("select * from cas where lif='" . $ent['lif'] . "'");

        	$html_str .=    "\n" .
        	                "\t<table class='table table-striped table-bordered' style='width:90% !important; margin:auto;'> \n" .
        	                "\t\t<tr><th colspan='7'><div class='text-center'>" . HARDWARE_CARD_TYPE_DIS . ":&nbsp;" . $ent['type'] ."&nbsp;&nbsp;" . HARDWARE_LINE_INTERFACE_DIS . ":&nbsp;" . $ent['lif'] . "&nbsp;&nbsp;</div></th></tr>\n";

        	while ($entry = $ba -> fetch_array($query))
		{
                	$html_str .=    "\t\t<tr>\n" .
                	                "\t\t\t<td><b>" . HARDWARE_PORT_DIS . ":</b>&nbsp;" . $entry['port'] . "&nbsp;</td>\n" .
                	                "\t\t\t<td colspan='4'>\n" .
                	                "\t\t\t\t<div class='col-sm-5'><b>" . HARDWARE_INTERFACE_TYPE_DIS . ":</b></div>\n" .
                	                "\t\t\t\t<div class='col-sm-7'>\n" .
                	                "\t\t\t\t\t<select class='form-control' name='interface_type" . $entry['port'] . "'>\n" .

                	                hw_mode("\t\t\t\t\t", $entry['port_type']) .

                	                "\t\t\t\t\t</select>\n" .
                	                "\t\t\t\t</div>\n" .
                	                "\t\t\t\t<input type=hidden name=id_upd[] value=" . $entry['port'] . ">\n" .
               	                	"\t\t\t\t<input type=hidden name=type[] value='cashw'>\n" .
                                	"\t\t\t</td>\n" .
                                	"\t\t\t<td>\n" .
                                	"\t\t\t\t<div class='col-sm-3'><b>" . HARDWARE_PROTOCOL_DIS . ":</b></div>\n" .
                                	"\t\t\t\t<div class='col-sm-7'>\n" .
                                	"\t\t\t\t\t<select class='form-control' name='t1e1" . $entry['port'] . "' onmouseover=\"Tip('" . "T1 or E1" . "')\" onmouseout='UnTip()'>\n" .

                               		hw_protocol ("\t\t\t\t\t", $entry['protocol']) .

                                	"\t\t\t\t\t</select>\n" .
                                	"\t\t\t\t</div>\n" .
                                	"\t\t\t\t<input type=hidden name=id_upd[] value=" . $entry['port'] . ">\n" .
                                	"\t\t\t\t<input type=hidden name=type[] value='cas'>\n" .
                                	"\t\t\t</td>\n" .
                                	"\t\t</tr>\n";
        	}
	}
	else 
	{
                exec("/bin/cat /sys/class/beronet/li*/module", $lifs);
                exec("/bin/cat /sys/class/beronet/gateway/li_count", $li_count); // not necessary; count($lifs) is enough

                for ($i=0; $i<$li_count[0]; $i++)
                {
                        if (preg_match("#t1e1#", $lifs[$i]))
                        {
                                $html_str .=    "\n" .
                                                "\t<table class='table table-striped table-bordered' style='width:90% !important; margin:auto;'> \n" .
                                                "\t\t<tr><th colspan='7'><div class='text-center'>" . HARDWARE_CARD_TYPE_DIS . ":&nbsp;" . $lifs[$i] ."&nbsp;&nbsp;" . HARDWARE_LINE_INTERFACE_DIS . ":&nbsp;" . $i . "&nbsp;&nbsp;</div></th></tr>\n";

                                $j = 1;
                                $nb_port = 1;
                                switch ($lifs[$i])
                                {
                                        case 'bf4t1e1':
                                                $nb_port = 4;
                                                break;
                                        case 'bf2t1e1':
                                                $nb_port = 2;
                                                break;
                                        case 'bf1t1e1':
                                        default:
                                                break;
                                }

				do
				{
                                	$html_str .=    "\t\t<tr>\n" .
                                        	        "\t\t\t<td><b>" . HARDWARE_PORT_DIS . ":</b>&nbsp; $j &nbsp;</td>\n" .
                                        	        "\t\t\t<td colspan='4'>\n" .
                                        	        "\t\t\t\t<div class='col-sm-5'><b>" . HARDWARE_INTERFACE_TYPE_DIS . ":</b></div>\n" .
                                        	        "\t\t\t\t<div class='col-sm-7'>\n" .
                                        	        "\t\t\t\t\t<select class='form-control' name='interface_type$j'>\n" .

                                        	        hw_mode("\t\t\t\t\t", "hdlc") .

                                       	        	"\t\t\t\t\t</select>\n" .
                                                	"\t\t\t\t</div>\n" .
                                                	"\t\t\t\t<input type=hidden name=id_upd[] value=$j>\n" .
                                                	"\t\t\t\t<input type=hidden name=type[] value='cashw'>\n" .
                                                	"\t\t\t</td>\n" .
                                                	"\t\t\t<td>\n" .
                                                	"\t\t\t\t<div class='col-sm-3'><b>" . HARDWARE_PROTOCOL_DIS . ":</b></div>\n" .
                                                	"\t\t\t\t<div class='col-sm-7'>\n" .
                                                	"\t\t\t\t\t<select class='form-control' name='t1e1$j' onmouseover=\"Tip('" . "T1 or E1" . "')\" onmouseout='UnTip()'>\n" .
	
         	                                      	hw_protocol ("\t\t\t\t\t", "e1") .

                                                	"\t\t\t\t\t</select>\n" .
                                                	"\t\t\t\t</div>\n" .
                                                	"\t\t\t\t<input type=hidden name=id_upd[] value=$j>\n" .
                                                	"\t\t\t\t<input type=hidden name=type[] value='cas'>\n" .
                                                	"\t\t\t</td>\n" .
                                                	"\t\t</tr>\n";

					$j++;
				}
				while ($j <= $nb_port);
                        }
                }

	}	

        $html_str .= "\t</table>\n";
}
while ($ent = $ba -> fetch_array($query_lif));

$html_str .=    "\t<div class='text-center' style='margin-top: 20px;'><input type='submit' class='btn btn-default' value='" . FACTORY_RESET_APPLY . "'></div>\n" .
                "</form>\n";

echo $html_str;
